turbofeeds.util

Package turbofeeds :: Module util |
[hide private]

# Module util

source code
TurboFeed utility functions.

Functions | [hide private]
absolute_url(suffix=`'````'`, params=None, **kw) Returns the absolute URL to this server, appending 'suffix' if given. | source code
xml_stylesheet(href, type=`'``text/css``'`) Returns an xml-stylesheet processing instruction element for given URL. | source code

Function Details | [hide private]

### xml_stylesheet(href, type=`'``text/css``'`) | source code
Returns an xml-stylesheet processing instruction element for given URL. `href` can be a string with the URL to the stylesheet or a dict with members `href` and `type` (see below) or a callable returning either. `type` specifies the value of the "type" atribute of the PI. The default type is 'text/css'.